@@ -1,5 +1,7 @@
 #' Add a 3D grid of nodes to the graph
 #'
+#' @description
+#'
 #' With a graph object of class `dgr_graph`, add a three-dimensional grid to the
 #' graph.
 #'
@@ -61,17 +63,19 @@
 #' graph_w_attrs %>% get_edge_df()
 #'
 #' @export
-add_grid_3d <- function(graph,
-                        x,
-                        y,
-                        z,
-                        type = NULL,
-                        label = TRUE,
-                        rel = NULL,
-                        node_aes = NULL,
-                        edge_aes = NULL,
-                        node_data = NULL,
-                        edge_data = NULL) {
+add_grid_3d <- function(
+    graph,
+    x,
+    y,
+    z,
+    type = NULL,
+    label = TRUE,
+    rel = NULL,
+    node_aes = NULL,
+    edge_aes = NULL,
+    node_data = NULL,
+    edge_data = NULL
+) {
 
   # Get the time of function start
   time_function_start <- Sys.time()
