@@ -1,5 +1,7 @@
 #' Get an aggregate value from the indegree of nodes
 #'
+#' @description
+#'
 #' Get a single, aggregate value from the indegree values for all nodes in a
 #' graph, or, a subset of graph nodes.
 #'
@@ -54,9 +56,11 @@
 #'
 #' @import rlang
 #' @export
-get_agg_degree_in <- function(graph,
-                              agg,
-                              conditions = NULL) {
+get_agg_degree_in <- function(
+    graph,
+    agg,
+    conditions = NULL
+) {
 
   # Get the name of the function
   fcn_name <- get_calling_fcn()
