@@ -1,6 +1,9 @@
 #' Get Dice similarity coefficient scores
 #'
+#' @description
+#'
 #' Get the Dice similarity coefficient scores for one or more nodes in a graph.
+#'
 #' @inheritParams render_graph
 #' @param nodes an optional vector of node IDs to consider for Dice similarity
 #'   scores. If not supplied, then similarity scores will be provided for every
@@ -34,10 +37,12 @@
 #'     nodes = 5:7)
 #'
 #' @export
-get_dice_similarity <- function(graph,
-                                nodes = NULL,
-                                direction = "all",
-                                round_to = 3) {
+get_dice_similarity <- function(
+    graph,
+    nodes = NULL,
+    direction = "all",
+    round_to = 3
+) {
 
   # Get the name of the function
   fcn_name <- get_calling_fcn()
