@@ -1,5 +1,7 @@
 #' Traverse from one or more selected nodes onto adjacent, outward nodes
 #'
+#' @description
+#'
 #' From a graph object of class `dgr_graph` move along outward edges from one or
 #' more nodes present in a selection to other connected nodes, replacing the
 #' current nodes in the selection with those nodes traversed to. An optional
@@ -205,12 +207,14 @@
 #'
 #' @import rlang
 #' @export
-trav_out <- function(graph,
-                     conditions = NULL,
-                     copy_attrs_from = NULL,
-                     copy_attrs_as = NULL,
-                     agg = "sum",
-                     add_to_selection = FALSE) {
+trav_out <- function(
+    graph,
+    conditions = NULL,
+    copy_attrs_from = NULL,
+    copy_attrs_as = NULL,
+    agg = "sum",
+    add_to_selection = FALSE
+) {
 
   # Get the time of function start
   time_function_start <- Sys.time()
