@@ -32,6 +32,7 @@ utils::globalVariables(
     "id.y",
     "id__",
     "indeg",
+    "indegree",
     "indegree_dist",
     "indegree_hist",
     "index",
@@ -47,6 +48,7 @@ utils::globalVariables(
     "node_edge__",
     "node_id",
     "outdeg",
+    "outdegree",
     "outdegree_dist",
     "outdegree_hist",
     "rel",
@@ -62,6 +64,7 @@ utils::globalVariables(
     "to.y",
     "to_label",
     "to_type",
+    "total_degree",
     "total_degree_dist",
     "total_degree_hist",
     "type",
