@@ -6,16 +6,20 @@ test_that("Graph backups for `add_balanced_tree()` works", {
   # Backup from `add_balanced_tree()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_balanced_tree(
       k = 2, h = 2)
 
   expect_equal(
-    list.files(path = path) %>% length(), 1)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `add_cycle()` works", {
@@ -24,15 +28,19 @@ test_that("Graph backups for `add_cycle()` works", {
   # Backup from `add_cycle()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_cycle(n = 6)
 
   expect_equal(
-    list.files(path = path) %>% length(), 2)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `add_edge()` works", {
@@ -41,9 +49,10 @@ test_that("Graph backups for `add_edge()` works", {
   # Backup from `add_edge()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_n_nodes(
@@ -53,7 +62,10 @@ test_that("Graph backups for `add_edge()` works", {
       to = 2)
 
   expect_equal(
-    list.files(path = path) %>% length(), 3)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `add_edge_clone()` works", {
@@ -62,9 +74,10 @@ test_that("Graph backups for `add_edge_clone()` works", {
   # Backup from `add_edge_clone()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_n_nodes(
@@ -78,7 +91,10 @@ test_that("Graph backups for `add_edge_clone()` works", {
       to = 3)
 
   expect_equal(
-    list.files(path = path) %>% length(), 4)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `add_edge_clone()` works", {
@@ -87,9 +103,10 @@ test_that("Graph backups for `add_edge_clone()` works", {
   # Backup from `add_edge_clone()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_n_nodes(
@@ -103,7 +120,10 @@ test_that("Graph backups for `add_edge_clone()` works", {
       to = 3)
 
   expect_equal(
-    list.files(path = path) %>% length(), 5)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `add_edge_df()` works", {
@@ -112,9 +132,10 @@ test_that("Graph backups for `add_edge_df()` works", {
   # Backup from `add_edge_df()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   ndf <-
     create_node_df(
@@ -139,7 +160,10 @@ test_that("Graph backups for `add_edge_df()` works", {
       edge_df = edf)
 
   expect_equal(
-    list.files(path = path) %>% length(), 6)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `add_edge_df()` works", {
@@ -148,9 +172,10 @@ test_that("Graph backups for `add_edge_df()` works", {
   # Backup from `add_edges_from_table()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_nodes_from_table(
@@ -162,7 +187,10 @@ test_that("Graph backups for `add_edge_df()` works", {
       from_to_map = iso_4217_code)
 
   expect_equal(
-    list.files(path = path) %>% length(), 7)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `add_edges_w_string()` works", {
@@ -171,9 +199,10 @@ test_that("Graph backups for `add_edges_w_string()` works", {
   # Backup from `add_edges_w_string()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_n_nodes(n = 4) %>%
@@ -181,7 +210,10 @@ test_that("Graph backups for `add_edges_w_string()` works", {
       edges = "1->2 1->3 2->4 2->3")
 
   expect_equal(
-    list.files(path = path) %>% length(), 8)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `add_forward_edges_ws()` works", {
@@ -190,9 +222,10 @@ test_that("Graph backups for `add_forward_edges_ws()` works", {
   # Backup from `add_forward_edges_ws()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_n_nodes(
@@ -205,7 +238,10 @@ test_that("Graph backups for `add_forward_edges_ws()` works", {
     add_forward_edges_ws(rel = "b")
 
   expect_equal(
-    list.files(path = path) %>% length(), 9)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `add_full_graph()` works", {
@@ -214,15 +250,19 @@ test_that("Graph backups for `add_full_graph()` works", {
   # Backup from `add_full_graph()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_full_graph(n = 5)
 
   expect_equal(
-    list.files(path = path) %>% length(), 10)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `add_gnm_graph()` works", {
@@ -231,15 +271,19 @@ test_that("Graph backups for `add_gnm_graph()` works", {
   # Backup from `add_gnm_graph()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_gnm_graph(n = 100, m = 120)
 
   expect_equal(
-    list.files(path = path) %>% length(), 11)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `add_gnp_graph()` works", {
@@ -248,15 +292,19 @@ test_that("Graph backups for `add_gnp_graph()` works", {
   # Backup from `add_gnp_graph()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_gnp_graph(n = 100, p = 0.05)
 
   expect_equal(
-    list.files(path = path) %>% length(), 12)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `add_node_clones_ws()` works", {
@@ -265,9 +313,10 @@ test_that("Graph backups for `add_node_clones_ws()` works", {
   # Backup from `add_node_clones_ws()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_gnm_graph(
@@ -276,7 +325,10 @@ test_that("Graph backups for `add_node_clones_ws()` works", {
     add_node_clones_ws()
 
   expect_equal(
-    list.files(path = path) %>% length(), 13)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `add_n_node_clones()` works", {
@@ -285,9 +337,10 @@ test_that("Graph backups for `add_n_node_clones()` works", {
   # Backup from `add_n_node_clones()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_gnm_graph(
@@ -297,7 +350,10 @@ test_that("Graph backups for `add_n_node_clones()` works", {
       node = 1)
 
   expect_equal(
-    list.files(path = path) %>% length(), 14)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `add_global_graph_attrs()` works", {
@@ -306,9 +362,10 @@ test_that("Graph backups for `add_global_graph_attrs()` works", {
   # Backup from `add_global_graph_attrs()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_global_graph_attrs(
@@ -317,7 +374,10 @@ test_that("Graph backups for `add_global_graph_attrs()` works", {
       attr_type = "node")
 
   expect_equal(
-    list.files(path = path) %>% length(), 15)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `delete_global_graph_attrs()` works", {
@@ -326,9 +386,10 @@ test_that("Graph backups for `delete_global_graph_attrs()` works", {
   # Backup from `delete_global_graph_attrs()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     delete_global_graph_attrs(
@@ -336,7 +397,10 @@ test_that("Graph backups for `delete_global_graph_attrs()` works", {
       attr_type = "graph")
 
   expect_equal(
-    list.files(path = path) %>% length(), 16)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `add_graph_action()` works", {
@@ -345,9 +409,10 @@ test_that("Graph backups for `add_graph_action()` works", {
   # Backup from `add_graph_action()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_gnm_graph(
@@ -359,7 +424,10 @@ test_that("Graph backups for `add_graph_action()` works", {
       action_name = "get_btwns")
 
   expect_equal(
-    list.files(path = path) %>% length(), 17)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `delete_graph_actions()` works", {
@@ -368,9 +436,10 @@ test_that("Graph backups for `delete_graph_actions()` works", {
   # Backup from `delete_graph_actions()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_gnm_graph(
@@ -384,7 +453,10 @@ test_that("Graph backups for `delete_graph_actions()` works", {
       actions = "get_btwns")
 
   expect_equal(
-    list.files(path = path) %>% length(), 18)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `reorder_graph_actions()` works", {
@@ -393,9 +465,10 @@ test_that("Graph backups for `reorder_graph_actions()` works", {
   # Backup from `reorder_graph_actions()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_gnm_graph(
@@ -414,7 +487,10 @@ test_that("Graph backups for `reorder_graph_actions()` works", {
       indices = c(2, 1))
 
   expect_equal(
-    list.files(path = path) %>% length(), 19)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `transform_to_complement_graph()` works", {
@@ -423,16 +499,20 @@ test_that("Graph backups for `transform_to_complement_graph()` works", {
   # Backup from `transform_to_complement_graph()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_cycle(n = 4) %>%
     transform_to_complement_graph()
 
   expect_equal(
-    list.files(path = path) %>% length(), 20)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `copy_node_attrs()` works", {
@@ -441,9 +521,10 @@ test_that("Graph backups for `copy_node_attrs()` works", {
   # Backup from `copy_node_attrs()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_path(
@@ -455,7 +536,10 @@ test_that("Graph backups for `copy_node_attrs()` works", {
       node_attr_to = color_2)
 
   expect_equal(
-    list.files(path = path) %>% length(), 21)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `copy_edge_attrs()` works", {
@@ -464,9 +548,10 @@ test_that("Graph backups for `copy_edge_attrs()` works", {
   # Backup from `copy_edge_attrs()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_path(
@@ -478,7 +563,10 @@ test_that("Graph backups for `copy_edge_attrs()` works", {
       edge_attr_to = color_2)
 
   expect_equal(
-    list.files(path = path) %>% length(), 22)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `colorize_node_attrs()` works", {
@@ -487,9 +575,10 @@ test_that("Graph backups for `colorize_node_attrs()` works", {
   # Backup from `colorize_node_attrs()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   graph <-
     create_graph(write_backups = TRUE) %>%
@@ -507,7 +596,10 @@ test_that("Graph backups for `colorize_node_attrs()` works", {
       alpha = 90)
 
   expect_equal(
-    list.files(path = path) %>% length(), 23)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `colorize_edge_attrs()` works", {
@@ -516,9 +608,10 @@ test_that("Graph backups for `colorize_edge_attrs()` works", {
   # Backup from `colorize_edge_attrs()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   graph <-
     create_graph(write_backups = TRUE) %>%
@@ -536,7 +629,10 @@ test_that("Graph backups for `colorize_edge_attrs()` works", {
       alpha = 90)
 
   expect_equal(
-    list.files(path = path) %>% length(), 24)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `drop_node_attrs()` works", {
@@ -545,9 +641,10 @@ test_that("Graph backups for `drop_node_attrs()` works", {
   # Backup from `drop_node_attrs()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_path(
@@ -558,7 +655,10 @@ test_that("Graph backups for `drop_node_attrs()` works", {
       node_attr = color)
 
   expect_equal(
-    list.files(path = path) %>% length(), 25)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `drop_edge_attrs()` works", {
@@ -567,9 +667,10 @@ test_that("Graph backups for `drop_edge_attrs()` works", {
   # Backup from `drop_edge_attrs()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_path(
@@ -580,7 +681,10 @@ test_that("Graph backups for `drop_edge_attrs()` works", {
       edge_attr = color)
 
   expect_equal(
-    list.files(path = path) %>% length(), 26)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `join_node_attrs()` works", {
@@ -589,9 +693,10 @@ test_that("Graph backups for `join_node_attrs()` works", {
   # Backup from `join_node_attrs()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   df <-
     data.frame(
@@ -603,7 +708,10 @@ test_that("Graph backups for `join_node_attrs()` works", {
     join_node_attrs(df = df)
 
   expect_equal(
-    list.files(path = path) %>% length(), 27)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `join_edge_attrs()` works", {
@@ -612,9 +720,10 @@ test_that("Graph backups for `join_edge_attrs()` works", {
   # Backup from `join_edge_attrs()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   df <-
     data.frame(
@@ -627,7 +736,10 @@ test_that("Graph backups for `join_edge_attrs()` works", {
     join_edge_attrs(df = df)
 
   expect_equal(
-    list.files(path = path) %>% length(), 28)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `mutate_node_attrs()` works", {
@@ -636,9 +748,10 @@ test_that("Graph backups for `mutate_node_attrs()` works", {
   # Backup from `mutate_node_attrs()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_path(
@@ -650,7 +763,10 @@ test_that("Graph backups for `mutate_node_attrs()` works", {
       half_weight = weight / 2)
 
   expect_equal(
-    list.files(path = path) %>% length(), 29)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `mutate_edge_attrs()` works", {
@@ -659,9 +775,10 @@ test_that("Graph backups for `mutate_edge_attrs()` works", {
   # Backup from `mutate_edge_attrs()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_path(
@@ -673,7 +790,10 @@ test_that("Graph backups for `mutate_edge_attrs()` works", {
       half_weight = weight / 2)
 
   expect_equal(
-      list.files(path = path) %>% length(), 30)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `mutate_node_attrs_ws()` works", {
@@ -682,9 +802,10 @@ test_that("Graph backups for `mutate_node_attrs_ws()` works", {
   # Backup from `mutate_node_attrs_ws()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_path(
@@ -696,8 +817,11 @@ test_that("Graph backups for `mutate_node_attrs_ws()` works", {
     mutate_node_attrs_ws(
       half_weight = weight / 2)
 
-    expect_equal(
-      list.files(path = path) %>% length(), 31)
+  expect_equal(
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `mutate_edge_attrs_ws()` works", {
@@ -706,9 +830,10 @@ test_that("Graph backups for `mutate_edge_attrs_ws()` works", {
   # Backup from `mutate_edge_attrs_ws()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_path(
@@ -720,8 +845,11 @@ test_that("Graph backups for `mutate_edge_attrs_ws()` works", {
     mutate_edge_attrs_ws(
       half_weight = weight / 2)
 
-    expect_equal(
-      list.files(path = path) %>% length(), 32)
+  expect_equal(
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `rename_node_attrs()` works", {
@@ -730,9 +858,10 @@ test_that("Graph backups for `rename_node_attrs()` works", {
   # Backup from `rename_node_attrs()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_path(
@@ -745,7 +874,10 @@ test_that("Graph backups for `rename_node_attrs()` works", {
       node_attr_to = weight_2)
 
   expect_equal(
-    list.files(path = path) %>% length(), 33)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `rename_edge_attrs()` works", {
@@ -754,9 +886,10 @@ test_that("Graph backups for `rename_edge_attrs()` works", {
   # Backup from `rename_edge_attrs()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_path(
@@ -769,7 +902,10 @@ test_that("Graph backups for `rename_edge_attrs()` works", {
       edge_attr_to = weight_2)
 
   expect_equal(
-    list.files(path = path) %>% length(), 34)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `recode_node_attrs()` works", {
@@ -778,9 +914,10 @@ test_that("Graph backups for `recode_node_attrs()` works", {
   # Backup from `recode_node_attrs()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_gnm_graph(
@@ -799,7 +936,10 @@ test_that("Graph backups for `recode_node_attrs()` works", {
       "rectangle -> triangle")
 
   expect_equal(
-    list.files(path = path) %>% length(), 35)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `recode_edge_attrs()` works", {
@@ -808,9 +948,10 @@ test_that("Graph backups for `recode_edge_attrs()` works", {
   # Backup from `recode_edge_attrs()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_path(
@@ -826,7 +967,10 @@ test_that("Graph backups for `recode_edge_attrs()` works", {
       "rectangle -> triangle")
 
   expect_equal(
-    list.files(path = path) %>% length(), 36)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `rescale_node_attrs()` works", {
@@ -835,9 +979,10 @@ test_that("Graph backups for `rescale_node_attrs()` works", {
   # Backup from `rescale_node_attrs()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_path(
@@ -851,7 +996,10 @@ test_that("Graph backups for `rescale_node_attrs()` works", {
       to_upper_bound = 1)
 
   expect_equal(
-    list.files(path = path) %>% length(), 37)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `rescale_edge_attrs()` works", {
@@ -860,9 +1008,10 @@ test_that("Graph backups for `rescale_edge_attrs()` works", {
   # Backup from `rescale_edge_attrs()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_path(
@@ -876,7 +1025,10 @@ test_that("Graph backups for `rescale_edge_attrs()` works", {
       to_upper_bound = 1)
 
   expect_equal(
-    list.files(path = path) %>% length(), 38)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `rev_edge_dir()` works", {
@@ -885,16 +1037,20 @@ test_that("Graph backups for `rev_edge_dir()` works", {
   # Backup from `rev_edge_dir()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_path(n = 2) %>%
     rev_edge_dir()
 
   expect_equal(
-    list.files(path = path) %>% length(), 39)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `rev_edge_dir_ws()` works", {
@@ -903,9 +1059,10 @@ test_that("Graph backups for `rev_edge_dir_ws()` works", {
   # Backup from `rev_edge_dir_ws()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_path(n = 3) %>%
@@ -913,7 +1070,10 @@ test_that("Graph backups for `rev_edge_dir_ws()` works", {
     rev_edge_dir_ws()
 
   expect_equal(
-    list.files(path = path) %>% length(), 40)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `set_node_position()` works", {
@@ -922,9 +1082,10 @@ test_that("Graph backups for `set_node_position()` works", {
   # Backup from `set_node_position()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_node() %>%
@@ -932,7 +1093,10 @@ test_that("Graph backups for `set_node_position()` works", {
       node = 1, x = 1, y = 1)
 
   expect_equal(
-    list.files(path = path) %>% length(), 41)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `nudge_node_positions_ws()` works", {
@@ -941,9 +1105,10 @@ test_that("Graph backups for `nudge_node_positions_ws()` works", {
   # Backup from `nudge_node_positions_ws()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_node() %>%
@@ -954,7 +1119,10 @@ test_that("Graph backups for `nudge_node_positions_ws()` works", {
       dx = 2, dy = 0)
 
   expect_equal(
-    list.files(path = path) %>% length(), 42)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
 
 test_that("Graph backups for `nudge_node_positions_ws()` works", {
@@ -963,9 +1131,10 @@ test_that("Graph backups for `nudge_node_positions_ws()` works", {
   # Backup from `nudge_node_positions_ws()`
   #
 
-  path <- tempdir()
-  on.exit(unlink(path))
-  setwd(path)
+  main_wd <- getwd()
+  random_dir <- paste(sample(letters[1:10], 10), collapse = "")
+  dir.create(random_dir)
+  setwd(random_dir)
 
   create_graph(write_backups = TRUE) %>%
     add_node() %>%
@@ -976,5 +1145,8 @@ test_that("Graph backups for `nudge_node_positions_ws()` works", {
       dx = 2, dy = 0)
 
   expect_equal(
-    list.files(path = path) %>% length(), 43)
+    list.files() %>% length(), 1)
+
+  setwd(main_wd)
+  unlink(random_dir, recursive = TRUE)
 })
